@@ -33,9 +33,6 @@ from .base_adapter import BaseSiteAdapter,  makeDate
 def getClass():
     return ArchiveOfOurOwnOrgAdapter
 
-
-logger = logging.getLogger(__name__)
-
 class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
 
     def __init__(self, config, url):
@@ -236,7 +233,7 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
         alist = soup.findAll('a', href=re.compile(r"/users/\w+/pseuds/.+"))
         if len(alist) < 1: # ao3 allows for author 'Anonymous' with no author link.
             self.story.setMetadata('author','Anonymous')
-            self.story.setMetadata('authorUrl','https://archiveofourown.org/')
+            self.story.setMetadata('authorUrl','https://' + self.getSiteDomain() + '/')
             self.story.setMetadata('authorId','0')
         else:
             for a in alist:
